@@ -24,7 +24,7 @@ import boto3
 import time
 from collections import defaultdict
 from botocore.exceptions import ClientError, ParamValidationError
-from datetime import datetime
+from datetime import datetime, timedelta
 from subprocess import PIPE
 
 def getVersion():
@@ -32,9 +32,8 @@ def getVersion():
 
 service_modules = ["ac-core", "ac-allowlist", "ac-automation", "ac-macro-security", "ac-migrations", "ac-proxy", "ac-utils"]
 
-CGREY    = '\33[90m'
-CGREEN    = '\033[92m'
-SLEEP = 5
+CGREY = '\33[90m'
+CGREEN = '\033[92m'
 
 @click.command()
 @click.option('--verbose', '-v', is_flag=True, help="Verbose output")
@@ -58,9 +57,11 @@ SLEEP = 5
 @click.option('--version','-v', help="Specify App version", default="")
 @click.option('--filter','-f', help="Filter the list of AWS Log Groups, used as a wildcard match", default="")
 @click.option('--log-group','-n', help="AWS Log Group name", default="")
+@click.option('--starting-hour','-sh', help="Number of hours to go back for the start of tailing log entries for an AWS Log Group, the default(0) is the current time.", default=0)
+@click.option('--disassociate-cname-flag','-dcf', help="Disassociate CNAME to avoid CNAME conflict error", default="False")
 @click.argument('command')
 @click.help_option("--help", "-h")
-def process(verbose, command, profile, env, stage, stack, app_suffix, build, api_domain, api_stage, app_api_domain, require_approval, tag, bitbucket_username, bitbucket_password, bitbucket_branch, bitbucket_tag_value, aws_home, disable_clone_prompt, version, filter, log_group):
+def process(verbose, command, profile, env, stage, stack, app_suffix, build, api_domain, api_stage, app_api_domain, require_approval, tag, bitbucket_username, bitbucket_password, bitbucket_branch, bitbucket_tag_value, aws_home, disable_clone_prompt, version, filter, log_group, starting_hour, disassociate_cname_flag):
     """
     Gathers information related to deployment and deploys the CDK stack
 
@@ -93,7 +94,7 @@ def process(verbose, command, profile, env, stage, stack, app_suffix, build, api
       run-pipeline  Run a Bitbucket pipeline for a service module
         Options:  --stack, --bitbucket-username, --bitbucket-password, --bitbucket-branch, --bitbucket-tag-value
       tail-lg       Tails the logs for a AWS CloudWatch Logs group, use --filter to narrow down the list of Log Groups.
-        Options:  --profile, --filter, --log-group
+        Options:  --profile, --filter, --log-group, --starting-hour
       version       Print version information for the Appfire SDK
 
     Learn more - https://wiki.appfire.com/x/x6gjCQ
@@ -128,7 +129,8 @@ def process(verbose, command, profile, env, stage, stack, app_suffix, build, api
         return
     if command.lower() == 'tail-lg':
         filter = list(filter.split(","))
-        tail_log_group(profile,filter,log_group)
+        start_time = datetime.today() - timedelta(hours=starting_hour)
+        tail_log_group(profile,filter,log_group,int(start_time.timestamp()))
         return
     
     logger.debug("checking environment " + env)
@@ -282,7 +284,7 @@ def process(verbose, command, profile, env, stage, stack, app_suffix, build, api
         app_domain = ".".join(domain.split(".")[2:]) if env == 'standalone' else "appfire.app"
         app_name = domain.split(".")[0].split("-")[0]
         #brand = domain.split(".")[1] if env != 'standalone' else "bobswift"
-        brand = domain.split(".")[1].replace('dts-','') if env == 'dts' else domain.split(".")[1]
+        brand = domain.split(".")[1].replace('dts-','') #if env == 'dts' else domain.split(".")[1]
         logger.info("brand : "+ brand)
         #print(brand)
         #print(domain.split("."))
@@ -294,7 +296,7 @@ def process(verbose, command, profile, env, stage, stack, app_suffix, build, api
 
         logger.debug("overriding cdk.json with supplied arguments")
         logger.info("AWS home=" + aws_home)
-        generate_cdk_json(logger, app_suffix, app_domain, env, stack, stage, brand, app_name)
+        generate_cdk_json(logger, app_suffix, app_domain, env, stack, stage, brand, app_name, disassociate_cname_flag)
         if stack == 'core':
             deploy_core(logger,app_name,api_stage,app_domain,brand,env,app_suffix,aws_home,aws_profile,registry_url,tag)
         elif stack == 'biz-service':
@@ -479,7 +481,7 @@ def deploy_service_module(logger,service_module,module_services_deploy,app_name,
 
     return True
 
-def generate_cdk_json(logger, app_suffix, app_domain, env, stack, stage, brand, app_name):
+def generate_cdk_json(logger, app_suffix, app_domain, env, stack, stage, brand, app_name, disassociate_cname_flag):
     '''dynamically prepare cdk.json based on command line arguments'''
     
     try:
@@ -489,7 +491,7 @@ def generate_cdk_json(logger, app_suffix, app_domain, env, stack, stage, brand,
                 if item == 'app':
                     json_data[
                         item] = "npx ts-node ./node_modules/ac-app-dist/bin/ac-app-dist.js " + app_name + " " + stage \
-                                + " " + app_domain + " client/dist " + brand + " " + env + " false " + app_suffix
+                                + " " + app_domain + " client/dist " + brand + " " + env + " false '" + app_suffix + "' " + disassociate_cname_flag
         with open('cdk.json', 'w') as file:
             json.dump(json_data, file, indent=2)
     except IOError:
@@ -684,7 +686,7 @@ def checkCDKEnvVariables():
         sys.exit(1)
 
 
-def tail_log_group(profile,filter,log_group_name):
+def tail_log_group(profile,filter,log_group_name,start_time):
     client = boto3.Session(profile_name=profile).client('logs')
 
     # Get a list of log groups (use filter if set)
@@ -719,22 +721,22 @@ def tail_log_group(profile,filter,log_group_name):
     else:
         log_group = log_group_name
 
+    return filter_log_events(client,log_group,start_time)
+
+def filter_log_events(client,log_group,start_time):
+
     filter_logs_events_kwargs = {
             "logGroupName": log_group,
             "interleaved": True,
-            "logStreamNamePrefix" : str(datetime.today().year)
+            "startTime": int(start_time)  * 1000
         }
 
-    return filter_log_events(filter_logs_events_kwargs)
-
-def filter_log_events(filter_logs_events_kwargs):
-    client = boto3.client('logs')
     try:
         for event in do_filter_log_events(client, filter_logs_events_kwargs):
             #yield event
             timestamp = event["timestamp"]
             timestamp /= 1000
-            print(CGREEN + str(datetime.fromtimestamp(timestamp)), "  " +  CGREY + event["message"],end='')
+            print(CGREEN + str(datetime.fromtimestamp(timestamp)), "  " +  CGREY + event["message"])
     except KeyboardInterrupt:
         return
 
@@ -763,8 +765,8 @@ def do_filter_log_events(client, filter_logs_events_kwargs):
         try:
             response = client.filter_log_events(
                 **filter_logs_events_kwargs)
-        except (ClientError, ParamValidationError):
-            sys.exit("Invalid MFA one time pass code")
+        except ClientError as error:
+            sys.exit(error)
 
         for event in response['events']:
             # For the case where we've hit the last page, we will be
